@@ -305,6 +305,20 @@ int pool_virtual_master_db_node_id(void)
 		return REAL_MASTER_NODE_ID;
 	}
 
+	/*
+	 * Check whether failover is in progress. If so, just abort this session.
+	 */
+	if (Req_info->switching)
+	{
+		POOL_SETMASK(&BlockSig);
+		ereport(WARNING,
+				(errmsg("failover/failback is in progress"),
+						errdetail("executing failover or failback on backend"),
+				 errhint("In a moment you should be able to reconnect to the database")));
+		POOL_SETMASK(&UnBlockSig);
+		child_exit(POOL_EXIT_AND_RESTART);
+	}
+
 	if (sc->in_progress && sc->query_context)
 	{
 		int node_id = sc->query_context->virtual_master_node_id;
