@@ -93,11 +93,15 @@ static int choose_db_node_id(char *str);
 static void child_will_go_down(int code, Datum arg);
 static int opt_sort(const void *a, const void *b);
 /*
- * non 0 means SIGTERM(smart shutdown) or SIGINT(fast shutdown) has arrived
+ * Non 0 means SIGTERM (smart shutdown) or SIGINT (fast shutdown) has arrived
  */
 volatile sig_atomic_t exit_request = 0;
 static volatile sig_atomic_t alarm_enabled = false;
 
+/*
+ * Ignore SIGUSR1 if requested. Used when DROP DATABASE is requested.
+ */
+volatile sig_atomic_t ignore_sigusr1 = 0;
 
 static int idle;		/* non 0 means this child is in idle state */
 static int accepted = 0;
@@ -912,12 +916,12 @@ static POOL_CONNECTION_POOL *connect_backend(StartupPacket *sp, POOL_CONNECTION
 	backend = pool_create_cp();
 	if (backend == NULL)
 	{
-		pool_send_error_message(frontend, sp->major, "XX000", "connection cache is full", "",
-								"increase max_pool", __FILE__, __LINE__);
+		pool_send_error_message(frontend, sp->major, "XX000", "all backend nodes are down, pgpool requires at least one valid node", "",
+								"repair the backend nodes and restart pgpool", __FILE__, __LINE__);
 		ereport(ERROR,
-			(errmsg("unable to connect to backend"),
-				errdetail("connection cache is full"),
-					errhint("increase the \"max_pool\" configuration value, current max_pool is %d",pool_config->max_pool)));
+				(errmsg("unable to connect to backend"),
+				 errdetail("all backend nodes are down, pgpool requires at least one valid node"),
+				 errhint("repair the backend nodes and restart pgpool")));
 	}
 	
 	PG_TRY();
@@ -1033,6 +1037,12 @@ static RETSIGTYPE close_idle_connection(int sig)
 	ConnectionInfo *info;
 	int save_errno = errno;
 
+	/*
+	 * DROP DATABSE is ongoing.
+	 */
+	if (ignore_sigusr1)
+		return;
+
 #ifdef NOT_USED
 	ereport(DEBUG1,
 			(errmsg("close connection request received")));
@@ -2178,7 +2188,7 @@ static void validate_backend_connectivity(int front_end_fd)
 		if(front_end_fd > 0)
 		{
 			POOL_CONNECTION *cp;
-			volatile StartupPacket *sp;
+			StartupPacket *volatile sp;
 
 			/* 
              * we do not want to report socket error, as above errors
